@@ -1,11 +1,14 @@
 #!/usr/bin/python3
 
 import asyncio
-from debmutate.changelog import ChangelogEditor
+from typing import Optional
+from debmutate.changelog import ChangelogEditor, Version
 import sys
 from lintian_brush.debbugs import find_archived_wnpp_bugs, find_wnpp_bugs
 from lintian_brush.fixer import net_access_allowed, report_result
 
+versioned_changed: Optional[Version] = None
+
 
 if not net_access_allowed():
     sys.exit(0)
@@ -16,7 +19,8 @@ with ChangelogEditor() as editor:
         sys.exit(0)
 
     loop = asyncio.get_event_loop()
-    wnpp_bugs = loop.run_until_complete(find_wnpp_bugs(editor.changelog[-1].package))
+    wnpp_bugs = loop.run_until_complete(
+        find_wnpp_bugs(editor.changelog[-1].package))
     if wnpp_bugs:
         certainty = 'certain'
     else:
@@ -32,12 +36,18 @@ with ChangelogEditor() as editor:
             continue
 
         if 'Initial release' in line:
-            editor.changelog[-1]._changes[i] = line + " Closes: #%s" % ', '.join([str(bugno) for (bugno, kind) in wnpp_bugs])
+            editor.changelog[-1]._changes[i] = line + (
+                " Closes: #%s" % ', '.join(
+                    [str(bugno) for (bugno, kind) in wnpp_bugs]))
             version_changed = editor.changelog[-1].version
             break
 
 
-report_result(
-    "Add %s bugs in %s." %
-    (', '.join(sorted(set([kind for (bugno, kind) in wnpp_bugs]))), version_changed),
-    certainty=certainty)
+if version_changed:
+    report_result(
+        "Add %s bugs in %s." %
+        (', '.join(
+            sorted(set(
+                [kind for (bugno, kind) in wnpp_bugs]))),
+            version_changed),
+        certainty=certainty)
