@@ -43,7 +43,8 @@ def guess_description(binary_name, all_binaries, summary=None):
     if summary is None:
         summary = upstream_metadata.get('X-Summary')
     try:
-        upstream_description = textwrap_description(upstream_metadata['X-Description'])
+        upstream_description = textwrap_description(
+            upstream_metadata['X-Description'])
     except KeyError:
         # Better than nothing..
         return summary
@@ -72,7 +73,7 @@ with control as updater:
         if not issue.should_fix():
             continue
         description = guess_description(
-            binary['Package'], updater.binaries, summary=summary)
+            binary['Package'], list(updater.binaries), summary=summary)
         if description and description != existing_description:
             binary['Description'] = description
             updated.append(binary['Package'])
