@@ -21,9 +21,13 @@ from lintian_brush.fixer import (
     LintianIssue,
     report_result,
     warn,
+    diligence,
     )
 
-COMMON_MANGLES = ['s/$/.asc/']
+COMMON_MANGLES = [
+    's/$/.%s/' % ext for ext in ['asc', 'pgp', 'gpg', 'sig', 'sign']]
+NUM_KEYS_TO_CHECK = 5
+RELEASES_TO_INSPECT = 5
 
 
 if not os.path.exists('debian/watch'):
@@ -37,10 +41,21 @@ for path in ['debian/upstream/signing-key.asc',
         has_keys = True
 
 
+def fetch_keys(keys):
+    import subprocess
+    try:
+        subprocess.check_call(['gpg', '--recv-keys'] + keys)
+    except subprocess.CalledProcessError:
+        return False
+    return True
+
+
 def sig_valid(sig):
     return sig.status == 0
 
 
+description = None
+
 with WatchEditor() as editor:
     if not editor.watch_file:
         sys.exit(0)
@@ -50,19 +65,31 @@ with WatchEditor() as editor:
     sigs_valid = []
     used_mangles: List[Optional[str]] = []
     for entry in wf.entries:  # noqa: C901
-        releases_without_sig = []
-        if entry.has_option('pgpsigurlmangle') and has_keys:
+        try:
+            pgpsigurlmangle = entry.get_option('pgpsigurlmangle')
+        except KeyError:
+            pgpsigurlmangle = None
+        if pgpsigurlmangle and has_keys:
             continue
         try:
             pgpmode = entry.get_option('pgpmode')
         except KeyError:
             pgpmode = 'default'
+        else:
+            if diligence() == 0:
+                continue
         if pgpmode in ('gittag', 'previous', 'next', 'self'):
             sys.exit(2)
-        for r in sorted(entry.discover(source_package_name()), reverse=True):
+        try:
+            releases = list(sorted(
+                entry.discover(source_package_name()), reverse=True))
+        except HTTPError as e:
+            warn('HTTP error accessing discovery URL %s: %s.' %
+                 (e.geturl(), e))
+            sys.exit(0)
+        for r in releases[:RELEASES_TO_INSPECT]:
             if r.pgpsigurl:
-                pgpsigurls = [
-                    (entry.get_option('pgpsigurlmangle'), r.pgpsigurl)]
+                pgpsigurls = [(pgpsigurlmangle, r.pgpsigurl)]
             else:
                 pgpsigurls = [
                     (mangle, apply_url_mangle(mangle, r.url))
@@ -81,9 +108,19 @@ with WatchEditor() as editor:
                     warn('Error verifying signature %s on %s: %s' % (
                          pgpsigurl, r.url, e))
                     continue
+                except gpg.errors.BadSignatures as e:
+                    if str(e).endswith(': No public key'):
+                        if not fetch_keys(
+                                [s.fpr for s in e.result.signatures]):
+                            warn('Unable to retrieve keys: %r' % (
+                                 e.result.signatures, ))
+                            sys.exit(2)
+                        gr = c.verify(actual, sig)[1]
+                    else:
+                        raise
+                signatures = gr.signatures
                 is_valid = True
-                for sig in gr.signatures:
-                    # TODO(jelmer): Check validity
+                for sig in signatures:
                     if not sig_valid(sig):
                         warn('Signature from %s in %s for %s not valid' % (
                              sig.fpr, pgpsigurl, r.url))
@@ -95,17 +132,28 @@ with WatchEditor() as editor:
                 break
             else:
                 used_mangles.append(None)
-        if not all(sigs_valid[:5]):
+        if not all(sigs_valid[:NUM_KEYS_TO_CHECK]):
             sys.exit(0)
-        common_mangles = set(used_mangles[:5])
-        if len(common_mangles) == 1:
-            new_mangle = common_mangles.pop()
+        found_common_mangles = set(used_mangles[:5])
+        active_common_mangles = set([x for x in found_common_mangles if x])
+        if pgpsigurlmangle is None and active_common_mangles:
             issue = LintianIssue(
                 'source', 'debian-watch-does-not-check-gpg-signature', ())
-            if new_mangle is not None and issue.should_fix():
-                entry.set_option('pgpsigurlmangle', new_mangle)
-                if len(used_mangles) == 1:
+            if issue.should_fix():
+                # If only a single mangle is used for all releases
+                # that have signatures, set that.
+                if len(active_common_mangles) == 1:
+                    new_mangle = active_common_mangles.pop()
+                    entry.set_option('pgpsigurlmangle', new_mangle)
+                # If all releases are signed, mandate it.
+                if len(found_common_mangles) == 1:
                     entry.set_option('pgpmode', 'mangle')
+                    description = "Check upstream PGP signatures."
+                else:
+                    # Otherwise, fall back to auto.
+                    entry.set_option('pgpmode', 'auto')
+                    description = (
+                        "Opportunistically check upstream PGP signatures.")
                 issue.report_fixed()
         if not has_keys and needed_keys:
             issue = LintianIssue(
@@ -121,9 +169,7 @@ with WatchEditor() as editor:
                             missing_keys.append(fpr)
                         f.write(key)
                     if missing_keys:
-                        import subprocess
-                        subprocess.check_call(
-                            ['gpg', '--recv-keys'] + missing_keys)
+                        fetch_keys(missing_keys)
                         for fpr in missing_keys:
                             key = c.key_export_minimal(fpr)
                             if not key:
@@ -132,6 +178,10 @@ with WatchEditor() as editor:
                             f.write(key)
 
                 issue.report_fixed()
+                if description is None:
+                    description = "Add upstream signing keys (%s)." % (
+                        ', '.join(missing_keys))
 
 
-report_result('Check upstream signatures.')
+if description:
+    report_result(description)
