@@ -28,7 +28,7 @@ def extract_licenses(synopsis):
     return ret
 
 
-try:
+try:  # noqa: C901
     with CopyrightEditor() as updater:
         if updater.copyright.header.license:
             if updater.copyright.header.license.text:
@@ -86,7 +86,7 @@ try:
                     certainty = 'possible'
 
         if extra_defined and not extra_used:
-            for paragraph in list(updater.copyright._Copyright__paragraphs):
+            for paragraph in list(updater.copyright.all_paragraphs()):
                 if not paragraph.license:
                     continue
                 issue = LintianIssue(
@@ -96,7 +96,7 @@ try:
                     continue
                 if paragraph.license.synopsis in extra_defined:
                     issue.report_fixed()
-                    updater.copyright._Copyright__paragraphs.remove(paragraph)
+                    updater.remove(paragraph)
 except (FileNotFoundError, NotMachineReadableError):
     pass
 else:
