@@ -18,15 +18,27 @@
 
 """Debhelper utility functions."""
 
-from functools import cache
+try:
+    from functools import cache
+except ImportError:
+    # Python < 3.8
+    from functools import lru_cache
+
+    def cache(user_function):
+        return lru_cache(maxsize=None)(user_function)
+
 import json
 import os
 import subprocess
-from typing import Dict, Optional, List, Callable
+from typing import Dict, Optional, List, Callable, Tuple
 
 from debian.changelog import Version
 from debmutate.control import drop_dependency, add_dependency
-from debmutate._rules import update_rules, dh_invoke_drop_with, dh_invoke_add_with
+from debmutate._rules import (
+    update_rules,
+    dh_invoke_drop_with,
+    dh_invoke_add_with,
+)
 
 DEBHELPER_BUILD_STEPS = ["configure", "build", "test", "install", "clean"]
 
@@ -41,24 +53,13 @@ def detect_debhelper_buildsystem(step: Optional[str] = None) -> Optional[str]:
     """
     if os.path.exists("configure.ac") or os.path.exists("configure.in"):
         return "autoconf"
+    env = dict(os.environ)
+    # Necessary for debhelper (<= 13.5.2), or it'll write debian/.debhelper
+    # files.
+    env['DH_NO_ACT'] = '1'
     output = subprocess.check_output(
-        [
-            "perl",
-            "-w",
-            "-MDebian::Debhelper::Dh_Lib",
-            "-MDebian::Debhelper::Dh_Buildsystems",
-            "-e",
-            """\
-Debian::Debhelper::Dh_Lib::init(inhibit_log=>1);
-my $b=Debian::Debhelper::Dh_Buildsystems::load_buildsystem(undef, %(step)s);\
-if (defined($b)) { print($b->NAME); } else { print("_undefined_"); }\
-"""
-            % {"step": ("'%s'" % step) if step is not None else "undef"},
-        ]
-    ).decode()
-    if output == "_undefined_":
-        return None
-    return output
+        ["dh_assistant", "which-build-system"], env=env).decode()
+    return json.loads(output)["build-system"]
 
 
 @cache
@@ -132,31 +133,33 @@ def write_rules_template(
 
 
 def drop_obsolete_maintscript_entries(
-        editor, should_remove: Callable[[str, Version], bool]) -> List[int]:
+        editor, should_remove: Callable[[str, Version], bool]
+        ) -> List[Tuple[int, str, Version]]:
     """Drop obsolete entries from a maintscript file.
 
     Args:
       editor: editor to use to access the maintscript
-      should_remove: callable to check whether a package/version tuple is obsolete
+      should_remove: callable to check whether a package/version tuple is
+        obsolete
     Returns:
-      list of indexes of entries that were removed
+      list of tuples with index, package, version of entries that were removed
     """
-    remove = []
+    remove: List[Tuple[int, str, Version]] = []
     comments = []
     entries_removed = []
     for i, entry in enumerate(list(editor.lines)):
         if isinstance(entry, str):
-            comments.append(i)
+            comments.append((i, None, None))
             continue
         prior_version = getattr(entry, "prior_version", None)
         if prior_version is not None:
             if should_remove(entry.package, Version(prior_version)):
                 remove.extend(comments)
-                remove.append(i)
+                remove.append((i, entry.package, Version(prior_version)))
                 entries_removed.append(i)
         comments = []
     removed = []
-    for i in reversed(remove):
+    for i, pkg, version in reversed(remove):
         removed.append(editor.lines[i])
         del editor.lines[i]
     return entries_removed
@@ -167,7 +170,8 @@ def drop_sequence(control, rules, sequence):
         control.source.get("Build-Depends", ""), "dh-" + sequence)
     if new_depends != control.source['Build-Depends']:
         def drop_with(line, target):
-            return dh_invoke_drop_with(line, sequence.replace('-', '_').encode())
+            return dh_invoke_drop_with(
+                line, sequence.replace('-', '_').encode())
         update_rules(drop_with)
     new_depends = drop_dependency(
         new_depends, "dh-sequence-" + sequence)
@@ -183,6 +187,7 @@ def add_sequence(control, rules, sequence):
 
     def add_with(line, target):
         if line.startswith(b'dh ') or line.startswith(b'dh_'):
-            return dh_invoke_add_with(line, sequence.replace('-', '_').encode())
+            return dh_invoke_add_with(
+                line, sequence.replace('-', '_').encode())
         return line
     update_rules(add_with)
