@@ -38,18 +38,24 @@ def overrides_paths() -> Iterator[str]:
                 yield entry.path
 
 
-def update_overrides(cb: Callable[[int, LintianOverride], LintianOverride]) -> None:
+def update_overrides(
+        cb: Callable[
+            [str, int, LintianOverride],
+            Optional[LintianOverride]]) -> None:
     """ "Call update_overrides_file on all overrides files.
 
     Args:
-      cb: Callback that modifies overrides; called with an Override object
+      cb: Callback that modifies overrides; called with path, linenumber and
+         an Override object
     """
     for path in overrides_paths():
-        update_overrides_file(cb, path=path)
+        update_overrides_file(
+            lambda lineno, override: cb(path, lineno, override),
+            path=path)
 
 
 def update_overrides_file(
-    cb: Callable[[int, LintianOverride], LintianOverride],
+    cb: Callable[[int, LintianOverride], Optional[LintianOverride]],
     path: str = "debian/source/lintian-overrides",
 ) -> bool:
     """Modify the overrides in a file.
@@ -82,7 +88,8 @@ def get_overrides(
     paths = []
     if type in ("source", None):
         paths.extend(
-            ["debian/source/lintian-overrides", "debian/source.lintian-overrides"]
+            ["debian/source/lintian-overrides",
+             "debian/source.lintian-overrides"]
         )
     if type in ("binary", None):
         if package is not None:
@@ -121,7 +128,8 @@ def override_exists(
       arch: Architecture
     """
     for override in get_overrides(type=type, package=package):
-        if override.matches(package=package, info=info, tag=tag, arch=arch, type=type):
+        if override.matches(
+                package=package, info=info, tag=tag, arch=arch, type=type):
             return True
     return False
 
@@ -131,31 +139,29 @@ async def get_unused_overrides(
 ) -> List[Tuple[str, str, Version, str]]:
     from .udd import connect_udd_mirror
 
-    udd = await connect_udd_mirror()
-
     args: List[str] = []
     extra = []
     for (type, name) in packages:
         extra.append(
-            "package = $%d AND package_type = $%d" % (len(args) + 1, len(args) + 2)
+            "package = $%d AND package_type = $%d" % (
+                len(args) + 1, len(args) + 2)
         )
         args.extend([name, type])
 
-    return list(
-        await udd.fetch(
-            """\
+    async with await connect_udd_mirror() as udd:
+        return list(
+            await udd.fetch(
+                """\
 select package, package_type, package_version, information
-from lintian where tag = 'unused-override' AND (%s)"""
-            % " OR ".join(extra),
-            *args
-        )
-    )
+from lintian where tag = 'unused-override' AND (%s)
+""" % " OR ".join(extra), *args))
 
 
 unused_overrides = None
 
 
-def remove_unused(control_paragraphs, ignore_tags=None) -> List[LintianOverride]:
+def remove_unused(
+        control_paragraphs, ignore_tags=None) -> List[LintianOverride]:
 
     if ignore_tags is None:
         ignore_tags = set()
@@ -184,14 +190,16 @@ def remove_unused(control_paragraphs, ignore_tags=None) -> List[LintianOverride]
             return True
         return False
 
-    def drop_override(lineno, override):
+    def drop_override(path, lineno, override):
         global unused_overrides
         if unused_overrides is None:
             import asyncio
 
             loop = asyncio.get_event_loop()
-            unused_overrides = loop.run_until_complete(get_unused_overrides(packages))
-        if is_unused(override, unused_overrides) and override.tag not in ignore_tags:
+            unused_overrides = loop.run_until_complete(
+                get_unused_overrides(packages))
+        if (is_unused(override, unused_overrides)
+                and override.tag not in ignore_tags):
             removed.append(override)
             return None
         return override
