@@ -126,14 +126,23 @@ class DropObsoleteDependsTests(TestCase):
         checker = DummyChecker({'simple': Version('1.1')}, {})
         orig = PkgRelation.parse('simple (>= 1.0)')
         self.assertEqual(
-            (PkgRelation.parse('simple'), PkgRelation.parse('simple (>= 1.0)')),
+            (PkgRelation.parse('simple'),
+             PkgRelation.parse('simple (>= 1.0)')),
             drop_obsolete_depends(orig, checker))
 
     def test_essential(self):
         checker = DummyChecker({'simple': Version('1.1')}, {'simple'})
         orig = PkgRelation.parse('simple (>= 1.0)')
         self.assertEqual(
-            ([], PkgRelation.parse('simple (>= 1.0)')), drop_obsolete_depends(orig, checker))
+            ([], PkgRelation.parse('simple (>= 1.0)')),
+            drop_obsolete_depends(orig, checker))
+
+    def test_debhelper(self):
+        checker = DummyChecker({'debhelper': Version('1.4')}, {})
+        orig = PkgRelation.parse('debhelper (>= 1.1)')
+        self.assertEqual(
+            (PkgRelation.parse('debhelper (>= 1.1)'), []),
+            drop_obsolete_depends(orig, checker))
 
     def test_other_essential(self):
         checker = DummyChecker({'simple': Version('1.1')}, {'simple'})
